package com.duben.roseplaylet.ui.activitys

import android.annotation.SuppressLint
import android.app.Dialog
import android.graphics.Color
import android.os.Handler
import android.os.Looper
import android.text.TextUtils
import android.view.View
import android.widget.TextView
import androidx.core.content.ContextCompat
import com.duben.roseplaylet.R
import com.duben.roseplaylet.manager.UserManager
import com.duben.roseplaylet.ui.activitys.base.BaseActivity
import com.duben.roseplaylet.ui.widgets.CustomDialogAsApple
import com.duben.roseplaylet.ui.widgets.DialogListener
import com.duben.roseplaylet.ui.widgets.DialogUtils
import com.duben.roseplaylet.utils.*
import com.duben.library.utils.nodoubleclick.AntiShake
import com.duben.roseplaylet.common.AppConfig
import kotlinx.android.synthetic.main.activity_settings.*
import kotlinx.android.synthetic.main.header_layout.*
import java.util.*

class SettingsActivity : BaseActivity(), View.OnClickListener {

    private val userManager by lazy { UserManager.getInstance() }

    override fun initViewsAndEvents() {
        initHeader()
        initLayout()
    }

    private fun initHeader() {
        tv_title.text = "设置"
        tv_title.setTextColor(Color.WHITE)
        iv_left_icon.visibility = View.VISIBLE
        iv_left_icon.setImageResource(R.mipmap.ic_arrow_white)
        line.visibility = View.GONE
    }

    override fun onResume() {
        super.onResume()

        if (userManager.userIsLogin()) {
            btn_login_out.visibility = View.VISIBLE
        } else {
            btn_login_out.visibility = View.GONE
        }
    }

    @SuppressLint("CutPasteId")
    private fun initLayout() {
        layout_phone.setOnClickListener(this)
        layout_cancel.setOnClickListener(this)
        layout_cache.setOnClickListener(this)
        layout_feedback.setOnClickListener(this)
        layout_about_us.setOnClickListener(this)
        btn_login_out.setOnClickListener(this)

        layout_phone.findViewById<TextView>(R.id.label_start).text = "手机绑定"
        if (!TextUtils.isEmpty(userManager.mobile)) {
            layout_phone.findViewById<TextView>(R.id.label_tv).text = userManager.mobile
        } else {
            layout_phone.findViewById<TextView>(R.id.label_tv).text = "未绑定"
        }
        layout_cancel.findViewById<TextView>(R.id.label_start).text = "注销账号"
        layout_cache.findViewById<TextView>(R.id.label_start).text = "清除图片缓存"
        layout_cache.findViewById<TextView>(R.id.label_tv).text = CacheUtil.getTotalCacheSize(this)
        layout_feedback.findViewById<TextView>(R.id.label_start).text = "意见反馈"
        layout_about_us.findViewById<TextView>(R.id.label_start).text = "关于我们"
    }

    override fun getContentViewLayoutID() = R.layout.activity_settings

    override fun isApplyKitKatTranslucency() = false

    override fun onClick(v: View?) {
        if (AntiShake.check(v?.id)) return

        when (v?.id) {
            R.id.iv_left_icon -> {
                onBackPressed()
            }
            R.id.layout_phone -> {
                if (TextUtils.isEmpty(userManager.mobile)) {
                    readyGo(BindMobileActivity::class.java)
                    return
                }
            }
            R.id.layout_cancel -> {
                cancelAccount()
            }
            R.id.layout_cache -> {
                clearDialog()
            }
            R.id.layout_about_us -> {
                readyGo(AboutUsActivity::class.java)
            }
            R.id.layout_feedback -> {
                readyGo(FeedbackActivity::class.java)
            }
            R.id.btn_login_out -> {
                backDialog()
            }
        }
    }

    private fun cancelAccount() {
        DialogUtils.showDialog(
            this,
            SpanUtils()
                .append("确认注销账户？")
                .setForegroundColor(ContextCompat.getColor(this, R.color.tv_message_recente_money))
                .create(),
            "提示",
            "确定",
            object : DialogListener() {
                override fun onClick(dialog: Dialog?, v: View?) {
                    dialog?.dismiss()
                    ToastUtil.show(this@SettingsActivity, "注销账户申请已发起!")
                    Handler(Looper.getMainLooper()).postDelayed({
                        finish()
                    }, 200)
                }
            })
    }

    private fun backDialog() {
        val cdaa = CustomDialogAsApple(context, object : DialogListener() {
            override fun onClick(dialog: Dialog?, v: View?) {
                dialog?.dismiss()
                when (v?.id) {
                    R.id.dialog_btn_left -> {
                        AppConfig.exitLoginMainRefresh = true
                        userManager.userLogout()
                        finish()
                    }
                }
            }
        })
        cdaa.setContent("确定要退出登录吗？")
        cdaa.setLeft("确定")
        cdaa.setRight("取消")
        cdaa.show()
    }

    private fun clearDialog() {
        val cdaa = CustomDialogAsApple(context, object : DialogListener() {
            override fun onClick(dialog: Dialog?, v: View?) {
                dialog?.dismiss()
                when (v?.id) {
                    R.id.dialog_btn_left -> {

                    }
                    R.id.dialog_btn_right -> {
                        CacheUtil.clearAllCache()
                        layout_cache.findViewById<TextView>(R.id.label_tv).text = "0KB"
                    }
                }
            }
        })
        cdaa.setTitle("提示")
        cdaa.setContent("确定清除缓存吗?")
        cdaa.setLeft("取消")
        cdaa.setRight("确定")
        cdaa.show()
    }
}